@@ -6,7 +6,6 @@
 */
 
 #include "identity.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "kidentitymanagementcore_debug.h"
 #include <KConfigGroup>
@@ -16,6 +15,7 @@ using namespace Qt::Literals::StringLiterals;
 #include <QHostInfo>
 #include <QMimeData>
 
+using namespace Qt::Literals::StringLiterals;
 using namespace KIdentityManagementCore;
 
 static Identity *identityNull = nullptr;
@@ -35,6 +35,7 @@ Identity::Identity(const QString &id, const QString &fullName, const QString &em
     // setDictionary( Sonnet::defaultLanguageName() );
     setProperty(QLatin1StringView(s_disabledFcc), false);
     setProperty(QLatin1StringView(s_defaultDomainName), QHostInfo::localHostName());
+    setProperty(QLatin1StringView(s_disabledSpam), false);
 }
 
 const Identity &Identity::null()
@@ -66,6 +67,11 @@ bool Identity::isNull() const
             ++i;
             continue;
         }
+        // Take into account that disableFcc == false for a null identity
+        if (key == QLatin1StringView(s_disabledSpam) && i.value().toBool() == false) {
+            ++i;
+            continue;
+        }
         // The uoid is 0 by default, so ignore this
         if (!(key == QLatin1StringView(s_uoid) && i.value().toUInt() == 0)) {
             if (!i.value().isNull() || (i.value().metaType().id() == QMetaType::QString && !i.value().toString().isEmpty())) {
@@ -127,7 +133,7 @@ bool Identity::mailingAllowed() const
 
 QString Identity::mimeDataType()
 {
-    return QStringLiteral("application/x-kmail-identity-drag");
+    return u"application/x-kmail-identity-drag"_s;
 }
 
 bool Identity::canDecode(const QMimeData *md)
@@ -181,7 +187,8 @@ QDataStream &KIdentityManagementCore::operator<<(QDataStream &stream, const KIde
                   << i.mPropertiesMap[QLatin1StringView(s_autocryptPrefer)] << i.mPropertiesMap[QLatin1StringView(s_encryptionOverride)]
                   << i.mPropertiesMap[QLatin1StringView(s_pgpautosign)] << i.mPropertiesMap[QLatin1StringView(s_pgpautoencrypt)]
                   << i.mPropertiesMap[QLatin1StringView(s_warnnotencrypt)] << i.mPropertiesMap[QLatin1StringView(s_warnnotsign)]
-                  << i.mPropertiesMap[QLatin1StringView(s_activities)] << i.mPropertiesMap[QLatin1StringView(s_enabledActivities)];
+                  << i.mPropertiesMap[QLatin1StringView(s_activities)] << i.mPropertiesMap[QLatin1StringView(s_enabledActivities)]
+                  << i.mPropertiesMap[QLatin1StringView(s_spam)] << i.mPropertiesMap[QLatin1StringView(s_disabledSpam)];
 }
 
 QDataStream &KIdentityManagementCore::operator>>(QDataStream &stream, KIdentityManagementCore::Identity &i)
@@ -201,7 +208,8 @@ QDataStream &KIdentityManagementCore::operator>>(QDataStream &stream, KIdentityM
         >> i.mPropertiesMap[QLatin1StringView(s_autocryptPrefer)] >> i.mPropertiesMap[QLatin1StringView(s_encryptionOverride)]
         >> i.mPropertiesMap[QLatin1StringView(s_pgpautosign)] >> i.mPropertiesMap[QLatin1StringView(s_pgpautoencrypt)]
         >> i.mPropertiesMap[QLatin1StringView(s_warnnotencrypt)] >> i.mPropertiesMap[QLatin1StringView(s_warnnotsign)]
-        >> i.mPropertiesMap[QLatin1StringView(s_activities)] >> i.mPropertiesMap[QLatin1StringView(s_enabledActivities)];
+        >> i.mPropertiesMap[QLatin1StringView(s_activities)] >> i.mPropertiesMap[QLatin1StringView(s_enabledActivities)]
+        >> i.mPropertiesMap[QLatin1StringView(s_spam)] >> i.mPropertiesMap[QLatin1StringView(s_disabledSpam)];
 
     i.setProperty(QLatin1StringView(s_uoid), uoid);
     return stream;
@@ -293,7 +301,7 @@ QString Identity::fullEmailAddr() const
         return mail;
     }
 
-    const QString specials(QStringLiteral("()<>@,.;:[]"));
+    const QString specials(u"()<>@,.;:[]"_s);
 
     QString result;
 
@@ -303,19 +311,19 @@ QString Identity::fullEmailAddr() const
     for (int i = 0; i < nameLength; i++) {
         if (specials.contains(name[i])) {
             needsQuotes = true;
-        } else if (name[i] == QLatin1Char('\\') || name[i] == QLatin1Char('"')) {
+        } else if (name[i] == u'\\' || name[i] == u'"') {
             needsQuotes = true;
-            result += QLatin1Char('\\');
+            result += u'\\';
         }
         result += name[i];
     }
 
     if (needsQuotes) {
-        result.insert(0, QLatin1Char('"'));
-        result += QLatin1Char('"');
+        result.insert(0, u'"');
+        result += u'"';
     }
 
-    result += " <"_L1 + mail + QLatin1Char('>');
+    result += " <"_L1 + mail + u'>';
 
     return result;
 }
@@ -463,6 +471,12 @@ QString Identity::fcc() const
     return verifyAkonadiId(str);
 }
 
+QString Identity::spam() const
+{
+    const QString str = property(QLatin1StringView(s_spam)).toString();
+    return verifyAkonadiId(str);
+}
+
 QString Identity::transport() const
 {
     return property(QLatin1StringView(s_transport)).toString();
@@ -623,6 +637,11 @@ void Identity::setFcc(const QString &str)
     setProperty(QLatin1StringView(s_fcc), str);
 }
 
+void Identity::setSpam(const QString &str)
+{
+    setProperty(QLatin1StringView(s_spam), str);
+}
+
 void Identity::setDrafts(const QString &str)
 {
     setProperty(QLatin1StringView(s_drafts), str);
@@ -661,9 +680,9 @@ void Identity::setPreferredCryptoMessageFormat(const QString &str)
 void Identity::setXFace(const QString &str)
 {
     QString strNew = str;
-    strNew.remove(QLatin1Char(' '));
-    strNew.remove(QLatin1Char('\n'));
-    strNew.remove(QLatin1Char('\r'));
+    strNew.remove(u' ');
+    strNew.remove(u'\n');
+    strNew.remove(u'\r');
     setProperty(QLatin1StringView(s_xface), strNew);
 }
 
@@ -675,9 +694,9 @@ void Identity::setXFaceEnabled(bool on)
 void Identity::setFace(const QString &str)
 {
     QString strNew = str;
-    strNew.remove(QLatin1Char(' '));
-    strNew.remove(QLatin1Char('\n'));
-    strNew.remove(QLatin1Char('\r'));
+    strNew.remove(u' ');
+    strNew.remove(u'\n');
+    strNew.remove(u'\r');
     setProperty(QLatin1StringView(s_face), strNew);
 }
 
@@ -728,6 +747,21 @@ void Identity::setDisabledFcc(bool disable)
     setProperty(QLatin1StringView(s_disabledFcc), disable);
 }
 
+bool Identity::disabledSpam() const
+{
+    const QVariant var = property(QLatin1StringView(s_disabledSpam));
+    if (var.isNull()) {
+        return false;
+    } else {
+        return var.toBool();
+    }
+}
+
+void Identity::setDisabledSpam(bool disable)
+{
+    setProperty(QLatin1StringView(s_disabledSpam), disable);
+}
+
 bool Identity::pgpAutoSign() const
 {
     const QVariant var = property(QLatin1StringView(s_pgpautosign));
