@@ -20,6 +20,7 @@
 #include <cassert>
 
 using namespace KIdentityManagementCore;
+using namespace Qt::Literals::StringLiterals;
 
 class KIdentityManagementCore::SignaturePrivate
 {
@@ -60,7 +61,7 @@ static QStringList findImageNames(const QString &htmlCode)
             const auto fragment = it.fragment();
             if (fragment.isValid()) {
                 const auto imageFormat = fragment.charFormat().toImageFormat();
-                if (imageFormat.isValid() && !imageFormat.name().startsWith(QLatin1String("http")) && !imageNames.contains(imageFormat.name())) {
+                if (imageFormat.isValid() && !imageFormat.name().startsWith("http"_L1) && !imageNames.contains(imageFormat.name())) {
                     imageNames.push_back(imageFormat.name());
                 }
             }
@@ -101,7 +102,7 @@ void SignaturePrivate::cleanupImages()
         QDir dir(saveLocation);
         const QStringList lst = dir.entryList(QDir::Files | QDir::NoDotAndDotDot | QDir::NoSymLinks);
         for (const QString &fileName : lst) {
-            if (fileName.endsWith(QLatin1String(".png"), Qt::CaseInsensitive)) {
+            if (fileName.endsWith(".png"_L1, Qt::CaseInsensitive)) {
                 qCDebug(KIDENTITYMANAGEMENT_LOG) << "Deleting old image" << dir.path() + fileName;
                 dir.remove(fileName);
             }
@@ -113,7 +114,7 @@ void SignaturePrivate::saveImages() const
 {
     if (inlinedHtml && !saveLocation.isEmpty()) {
         for (const Signature::EmbeddedImagePtr &image : std::as_const(embeddedImages)) {
-            const QString location = saveLocation + QLatin1Char('/') + image->name;
+            const QString location = saveLocation + u'/' + image->name;
             if (!image->image.save(location, "PNG")) {
                 qCWarning(KIDENTITYMANAGEMENT_LOG) << "Failed to save image" << location;
             }
@@ -270,17 +271,17 @@ QString Signature::withSeparator(bool *ok, QString *errorMessage) const
     }
 
     const bool htmlSig = (isInlinedHtml() && d->type == Inlined);
-    QString newline = htmlSig ? QStringLiteral("<br>") : QStringLiteral("\n");
-    if (htmlSig && signature.startsWith(QLatin1String("<p"))) {
+    QString newline = htmlSig ? u"<br>"_s : u"\n"_s;
+    if (htmlSig && signature.startsWith("<p"_L1)) {
         newline.clear();
     }
 
-    if (signature.startsWith(QLatin1String("-- ") + newline) || (signature.indexOf(newline + QLatin1String("-- ") + newline) != -1)) {
+    if (signature.startsWith("-- "_L1 + newline) || (signature.indexOf(newline + "-- "_L1 + newline) != -1)) {
         // already have signature separator at start of sig or inside sig:
         return signature;
     } else {
         // need to prepend one:
-        return QLatin1String("-- ") + newline + signature;
+        return "-- "_L1 + newline + signature;
     }
 }
 
@@ -316,16 +317,16 @@ static const char sigEnabled[] = "Signature Enabled";
 void Signature::readConfig(const KConfigGroup &config)
 {
     QString sigType = config.readEntry(sigTypeKey);
-    if (sigType == QLatin1String(sigTypeInlineValue)) {
+    if (sigType == QLatin1StringView(sigTypeInlineValue)) {
         d->type = Inlined;
         d->inlinedHtml = config.readEntry(sigTypeInlinedHtmlKey, false);
-    } else if (sigType == QLatin1String(sigTypeFileValue)) {
+    } else if (sigType == QLatin1StringView(sigTypeFileValue)) {
         d->type = FromFile;
         d->path = config.readPathEntry(sigFileKey, QString());
-    } else if (sigType == QLatin1String(sigTypeCommandValue)) {
+    } else if (sigType == QLatin1StringView(sigTypeCommandValue)) {
         d->type = FromCommand;
         d->path = config.readPathEntry(sigCommandKey, QString());
-    } else if (sigType == QLatin1String(sigTypeDisabledValue)) {
+    } else if (sigType == QLatin1StringView(sigTypeDisabledValue)) {
         d->enabled = false;
     }
     if (d->type != Disabled) {
@@ -339,12 +340,12 @@ void Signature::readConfig(const KConfigGroup &config)
         QDir dir(d->saveLocation);
         const QStringList lst = dir.entryList(QDir::Files | QDir::NoDotAndDotDot | QDir::NoSymLinks);
         for (const QString &fileName : lst) {
-            if (fileName.endsWith(QLatin1String(".png"), Qt::CaseInsensitive)) {
+            if (fileName.endsWith(".png"_L1, Qt::CaseInsensitive)) {
                 QImage image;
-                if (image.load(dir.path() + QLatin1Char('/') + fileName)) {
+                if (image.load(dir.path() + u'/' + fileName)) {
                     addImage(image, fileName);
                 } else {
-                    qCWarning(KIDENTITYMANAGEMENT_LOG) << "Unable to load image" << dir.path() + QLatin1Char('/') + fileName;
+                    qCWarning(KIDENTITYMANAGEMENT_LOG) << "Unable to load image" << dir.path() + u'/' + fileName;
                 }
             }
         }
